#[unsafe(no_mangle)]pub extern "C" fn module_load_event(
_drctx: *mut c_void,
module_ptr: *const module_data_t,
_loaded: bool,
)Expand description
Called by DynamoRio when each C module is loaded. Each .dll will be a module, and the main binary itself will be comprised of one or more modules.